summaryrefslogtreecommitdiff
path: root/compiler/GHC/Hs/Expr.hs
diff options
context:
space:
mode:
Diffstat (limited to 'compiler/GHC/Hs/Expr.hs')
-rw-r--r--compiler/GHC/Hs/Expr.hs16
1 files changed, 8 insertions, 8 deletions
diff --git a/compiler/GHC/Hs/Expr.hs b/compiler/GHC/Hs/Expr.hs
index 52162a09c8..c34e7eb809 100644
--- a/compiler/GHC/Hs/Expr.hs
+++ b/compiler/GHC/Hs/Expr.hs
@@ -38,11 +38,11 @@ import GHC.Hs.Binds
-- others:
import TcEvidence
import GHC.Core
-import Name
-import NameSet
-import BasicTypes
+import GHC.Types.Name
+import GHC.Types.Name.Set
+import GHC.Types.Basic
import GHC.Core.ConLike
-import SrcLoc
+import GHC.Types.SrcLoc
import Util
import Outputable
import FastString
@@ -675,7 +675,7 @@ type instance XXExpr GhcTc = HsWrap HsExpr
-- | A pragma, written as {-# ... #-}, that may appear within an expression.
data HsPragE p
= HsPragSCC (XSCC p)
- SourceText -- Note [Pragma source text] in BasicTypes
+ SourceText -- Note [Pragma source text] in GHC.Types.Basic
StringLiteral -- "set cost centre" SCC pragma
-- | - 'ApiAnnotation.AnnKeywordId' : 'ApiAnnotation.AnnOpen' @'{-\# CORE'@,
@@ -683,7 +683,7 @@ data HsPragE p
-- For details on above see note [Api annotations] in ApiAnnotation
| HsPragCore (XCoreAnn p)
- SourceText -- Note [Pragma source text] in BasicTypes
+ SourceText -- Note [Pragma source text] in GHC.Types.Basic
StringLiteral -- hdaume: core annotation
-- | - 'ApiAnnotation.AnnKeywordId' : 'ApiAnnotation.AnnOpen',
@@ -698,12 +698,12 @@ data HsPragE p
-- For details on above see note [Api annotations] in ApiAnnotation
| HsPragTick -- A pragma introduced tick
(XTickPragma p)
- SourceText -- Note [Pragma source text] in BasicTypes
+ SourceText -- Note [Pragma source text] in GHC.Types.Basic
(StringLiteral,(Int,Int),(Int,Int))
-- external span for this tick
((SourceText,SourceText),(SourceText,SourceText))
-- Source text for the four integers used in the span.
- -- See note [Pragma source text] in BasicTypes
+ -- See note [Pragma source text] in GHC.Types.Basic
| XHsPragE (XXPragE p)